==> v-sim_3.6.0.orig.tar.gz: v_sim-3.6.0/src/gtk_pick.h <==
/*   EXTRAITS DE LA LICENCE
	Copyright CEA, contributeurs : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)
  
	Adresse ml :
	BILLARD, non joignable par ml ;
	CALISTE, damien P caliste AT cea P fr.

	Ce logiciel est un programme informatique servant  visualiser des
	structures atomiques dans un rendu pseudo-3D. 

	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
	respectant les principes de diffusion des logiciels libres. Vous pouvez
	utiliser, modifier et/ou redistribuer ce programme sous les conditions
	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
	sur le site "http://www.cecill.info".

	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
	pris connaissance de la licence CeCILL, et que vous en avez accept les
	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
*/

/*   LICENCE SUM UP
	Copyright CEA, contributors : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)

	E-mail address:
	BILLARD, not reachable any more ;
	CALISTE, damien P caliste AT cea P fr.

	This software is a computer program whose purpose is to visualize atomic
	configurations in 3D.

	This software is governed by the CeCILL  license under French law and
	abiding by the rules of distribution of free software.  You can  use, 
	modify and/ or redistribute the software under the terms of the CeCILL
	license as circulated by CEA, CNRS and INRIA at the following URL
	"http://www.cecill.info". 

	The fact that you are presently reading this means that you have had
	knowledge of the CeCILL license and that you accept its terms. You can
	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
*/

#ifndef GTK_PICK_H
#define GTK_PICK_H

#include <glib.h>

#include "gtk_main.h"
#include "gtk_renderingWindowWidget.h"

/**
 * gtkPickBuild_interface:
 * @main: the main interface.
 * @label: a location to store the name of the pick tab ;
 * @help: a location to store the help message to be shown at the
 * bottom of the window ;
 * @radio: a location on the radio button that will be toggled when
 * the pick action is used.
 * 
 * This routine should be called in conjonction to the
 * create_observeDialog() one. It completes the creation of widgets
 * (and also initialisation of values) for the pick tab.
 */
GtkWidget* gtkPickBuild_interface(VisuUiMain *main, gchar **label,
				  gchar **help, GtkWidget **radio);
void gtkPickStart(VisuRenderingWindow *window);
void gtkPickStop(VisuRenderingWindow *window);
/**
 * gtkPickGet_nodeSelection:
 *
 * Compute a list of #VisuNode currently listed.
 *
 * Returns: a newly created list. Should be freed with g_list_free()
 * after use.
 */
GList* gtkPickGet_nodeSelection();
/**
 * gtkPick_onClose:
 *
 * A routine to be called when the interactive window is closed. It
 * currently cleans the labels for the pick information.
 */
void gtkPick_onClose();
/**
 * gtkPickParse_XMLFile:
 * @filename: a filename ;
 * @data: a #VisuData object to take the pick information from ;
 * @error: a location to store possible errors.
 *
 * Parse the given V_Sim value file and update the dialog accordingly.
 *
 * Returns: TRUE if no error.
 */
gboolean gtkPickParse_XMLFile(const gchar* filename, VisuData *data, GError **error);

void initGtkPick();

#endif

==> v-sim_3.7.2.orig.tar.gz: v_sim-3.7.2/src/gtk_pick.h <==
/*   EXTRAITS DE LA LICENCE
	Copyright CEA, contributeurs : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)
  
	Adresse ml :
	BILLARD, non joignable par ml ;
	CALISTE, damien P caliste AT cea P fr.

	Ce logiciel est un programme informatique servant  visualiser des
	structures atomiques dans un rendu pseudo-3D. 

	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
	respectant les principes de diffusion des logiciels libres. Vous pouvez
	utiliser, modifier et/ou redistribuer ce programme sous les conditions
	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
	sur le site "http://www.cecill.info".

	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
	pris connaissance de la licence CeCILL, et que vous en avez accept les
	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
*/

/*   LICENCE SUM UP
	Copyright CEA, contributors : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)

	E-mail address:
	BILLARD, not reachable any more ;
	CALISTE, damien P caliste AT cea P fr.

	This software is a computer program whose purpose is to visualize atomic
	configurations in 3D.

	This software is governed by the CeCILL  license under French law and
	abiding by the rules of distribution of free software.  You can  use, 
	modify and/ or redistribute the software under the terms of the CeCILL
	license as circulated by CEA, CNRS and INRIA at the following URL
	"http://www.cecill.info". 

	The fact that you are presently reading this means that you have had
	knowledge of the CeCILL license and that you accept its terms. You can
	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
*/

#ifndef GTK_PICK_H
#define GTK_PICK_H

#include <glib.h>

#include "gtk_main.h"
#include "gtk_renderingWindowWidget.h"

GtkWidget* visu_ui_interactive_pick_initBuild(VisuUiMain *main, gchar **label,
                                              gchar **help, GtkWidget **radio);
void visu_ui_interactive_pick_start(VisuUiRenderingWindow *window);
void visu_ui_interactive_pick_stop(VisuUiRenderingWindow *window);
GList* visu_ui_interactive_pick_getNodeSelection();
gboolean visu_ui_interactive_pick_parseXMLFile(const gchar* filename,
                                               VisuData *data, GError **error);
gboolean visu_ui_interactive_pick_exportXMLFile(const gchar *filename, GError **error);

void visu_ui_interactive_pick_init();

#endif
